@@ -92,6 +92,8 @@ AppWindow::AppWindow( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>&
 
 #ifdef _WIN32
     m_Hb_main->set_decoration_layout( ":minimize,maximize,close" );
+#elif GTK_CHECK_VERSION(4, 18, 0)
+    m_Hb_main->set_use_native_controls( true );
 #endif
 
     Lifeograph::icons->diary_32 = Gdk::Pixbuf::create_from_file(
@@ -338,24 +340,32 @@ AppWindow::show_entry( Entry* entry )
 }
 
 void
-AppWindow::go_to_prev()
+AppWindow::go_to_prev( bool F_include_invisibles )
 {
-    // get_prev_straight is not very meaningful here
-    Entry* entry_prev{ UI_entry->get_cur_entry()->get_prev() };
-
-    if( !entry_prev )
-        entry_prev = UI_entry->get_cur_entry()->get_parent();
-
-    if( entry_prev )
-        show_entry( entry_prev );
+    for( Entry* entry_prev = UI_entry->get_cur_entry()->get_prev_straight();
+         entry_prev;
+         entry_prev = entry_prev->get_prev_straight() )
+    {
+        if( F_include_invisibles || !entry_prev->is_filtered_out() )
+        {
+            show_entry( entry_prev );
+            break;
+        }
+    }
 }
 void
-AppWindow::go_to_next()
+AppWindow::go_to_next( bool F_include_invisibles )
 {
-    Entry* entry_next{ UI_entry->get_cur_entry()->get_next_straight() };
-
-    if( entry_next )
-        show_entry( entry_next );
+    for( Entry* entry_next = UI_entry->get_cur_entry()->get_next_straight();
+         entry_next;
+         entry_next = entry_next->get_next_straight() )
+    {
+        if( F_include_invisibles || !entry_next->is_filtered_out() )
+        {
+            show_entry( entry_next );
+            break;
+        }
+    }
 }
 
 void
@@ -514,19 +524,19 @@ AppWindow::handle_login()
         m_Pd_extra->set_position( Lifeograph::settings.position_paned_extra );
 
         // ACTIONS
-        using VInt = Glib::Variant< int >;
+        // using VInt = Glib::Variant< int >;
         Lifeograph::p->add_action( "undo", [ this ](){ handle_undo(); } );
         Lifeograph::p->set_accel_for_action( "app.undo", "<Ctrl>Z" );
         Lifeograph::p->add_action( "redo", [ this ](){ handle_redo(); } );
         Lifeograph::p->set_accel_for_action( "app.redo", "<Ctrl><Shift>Z" );
-        Lifeograph::p->add_action_with_parameter(
-                "show_elem",
-                VInt::variant_type(),
-	            []( const Glib::VariantBase& value )
-	            {
-                    const DEID id{ Glib::VariantBase::cast_dynamic< VInt >( value ).get() };
-                    AppWindow::p->show_elem( id );
-                } );
+        // Lifeograph::p->add_action_with_parameter(
+        //         "show_elem",
+        //         VInt::variant_type(),
+	       //      []( const Glib::VariantBase& value )
+	       //      {
+        //             const DEID id{ Glib::VariantBase::cast_dynamic< VInt >( value ).get() };
+        //             AppWindow::p->show_elem( id );
+        //         } );
     }
 
     init_textview_theme_classes();
