@@ -22,8 +22,8 @@
 
 #include "../lifeograph.hpp"
 #include "../app_window.hpp"
-#include "dialog_export.hpp"
 #include "dialog_sync.hpp"
+#include "dialog_password.hpp"
 
 
 using namespace LIFEO;
@@ -54,6 +54,7 @@ DialogSync::DialogSync( BaseObjectType* cobject, const Glib::RefPtr< Gtk::Builde
         m_TS_content = TreeStoreImport::create();
         m_B_go              = builder->get_widget< Gtk::Button >( "B_sync_go" );
         m_B_cancel          = builder->get_widget< Gtk::Button >( "B_sync_cancel" );
+        m_B_unlock          = builder->get_widget< Gtk::Button >( "B_sync_unlock" );
         m_IB_sync           = builder->get_widget< Gtk::InfoBar >( "IB_sync" );
         m_L_info            = builder->get_widget< Gtk::Label >( "L_sync_info" );
         m_FCB_diary         = Gtk::Builder::get_widget_derived< FileChooserButton >(
@@ -229,8 +230,10 @@ DialogSync::DialogSync( BaseObjectType* cobject, const Glib::RefPtr< Gtk::Builde
     m_B_ow->signal_clicked().connect(
             sigc::bind( sigc::mem_fun( *this, &DialogSync::change_action ), SI::OVERWRITE ) );
 
+    m_FCB_diary->signal_clicked().connect( [&](){ set_not_ready(); } );
     m_FCB_diary->m_signal_file_set.connect(
             sigc::mem_fun( *this, &DialogSync::open_remote_diary ) );
+    m_B_unlock->signal_clicked().connect( [&](){ ask_for_password(); } );
 
     m_B_go->signal_clicked().connect(
             [ this ]()
@@ -248,11 +251,12 @@ void
 DialogSync::on_show()
 {
     Gtk::Window::on_show();
-    set_not_ready( _( "Select a diary file for synchronizing" ) );
+    set_not_ready();
 
     m_Bx_operations->set_visible( false );
 
     m_FCB_diary->set_uri( "" );
+    m_B_unlock->hide();
     m_WEP_widget->clear();
 
     m_FCB_diary->grab_focus();
@@ -271,7 +275,12 @@ DialogSync::open_remote_diary( const String& uri )
         if( m_diary_r->read_header() == SUCCESS )
         {
             if( m_diary_r->is_encrypted() )
-                ask_for_password();
+                // Glib::signal_idle().connect_once(
+                //     sigc::mem_fun( *this, &DialogSync::ask_for_password ) );
+                // ask_for_password();
+                // TODO: 3.2: popover cannot be shown in a Filechooser event any more...
+                // ...so we use an intermediary unlock button to tringger the password popover
+                m_B_unlock->set_visible();
             else
                 open_remote_diary2();
         }
@@ -305,6 +314,7 @@ void
 DialogSync::open_remote_diary3()
 {
     DialogPassword::finish( m_diary_r->get_uri() );
+    m_B_unlock->hide();
     m_P_contents->set_position( get_height() * 0.55 );
     m_RB_changed_ignore->set_active( true );
     m_RB_new_ignore->set_active( true );
@@ -330,10 +340,13 @@ DialogSync::open_remote_diary3()
 void
 DialogSync::ask_for_password()
 {
+    auto            gphrect { m_B_unlock->compute_bounds( *this ) };
+    Gdk::Rectangle  rect    { int( gphrect->get_x() ),      int( gphrect->get_y() ),
+                              int( gphrect->get_width() ),  int( gphrect->get_height() ) };
     DialogPassword::launch( DialogPassword::OT_OPEN,
-                            m_diary_r, nullptr, m_FCB_diary,
+                            m_diary_r, &rect, this,
                             sigc::mem_fun( *this, &DialogSync::open_remote_diary2 ),
-                            [ this ]() { m_FCB_diary->set_uri( "" ); } );
+                            [ this ]() { m_B_unlock->hide(); m_FCB_diary->set_uri( "" ); } );
 }
 
 void
@@ -906,7 +919,7 @@ DialogSync::go_synchonize()
     if( m_action_map[ m_diary_r->get_id() ] != SI::SI_IGNORE )
         Diary::d->synchronize_options( m_diary_r );
 
-    set_not_ready( "" );
+    set_not_ready();
 
     hide();
 }
