@@ -269,7 +269,7 @@ namespace VT
     REG_PROP_ALIAS( DEFAULT, CHAR_COUNT );
     REG_PROP_XTRA( FILTER, 0x0F );
     REG_PROP_END;
-    // TODO: v3.1 or later:  REG_PROP_INTR( 1, 0, 'W', 0x02, WORD_COUNT, N_( "Word Count" ) );
+    // TODO: 3.1 or later:  REG_PROP_INTR( 1, 0, 'W', 0x02, WORD_COUNT, N_( "Word Count" ) );
 
     // TABLE COLUMN OPTIONS: DURATION
     static constexpr char TCD_CHARS[]           = "_SCHFN12";
@@ -463,7 +463,7 @@ namespace VT
                          HFT_FOLD_COLLAPSED = 25 | HFT_F_LINK | HFT_F_ALWAYS | HFT_F_NOT_SAVED,
                          HFT_DATE_ELLIPSIS  = 61 | HFT_F_ONTHEFLY,
                          HFT_UNSET          = 99;
-                        // TODO: combine ON_THE_FLY and NOT_SAVED?
+                        // TODO: 3.2: combine ON_THE_FLY and NOT_SAVED?
 }
 
 typedef int SortCriterion;
@@ -499,6 +499,7 @@ static const DEID DEID_MIN           = 10000;     // ids had to be greater than
                                                   // all standard ids have to be less than this
 static const DEID DEID_MIN_ACTUAL    = 10000000;  // ids have to be greater than this
 static const DEID DEID_UNSET         = 404;       // :)
+static const DEID DEID_MULTIPLE      = 606;
 static const DEID HOME_CURRENT_ENTRY = 1;         // entry shown at startup
 static const DEID HOME_LAST_ENTRY    = 2;         // entry shown at startup
 // NOTE: when HOME is fixed element, elements ID is used
@@ -755,6 +756,22 @@ using SignalVoidElem            = sigc::signal< void( LIFEO::DiaryElement* ) >;
 using SignalVoidElemstatus      = sigc::signal< void( LIFEO::ElemStatus ) >;
 using FuncVoidElem              = std::function< void( DiaryElement* ) >;
 
+template< class T >
+class MapUstringDiaryElem : public std::map< Ustring, T*, FuncCmpStrings >
+{
+public:
+    ~MapUstringDiaryElem() { clear(); }
+
+    void
+    clear()
+    {
+        for( auto kv : *this )
+            delete kv.second;
+
+        std::map< Ustring, T*, FuncCmpStrings >::clear();
+    }
+};
+
 template< class T >
 Ustring
 create_unique_name_for_map( const std::map< Ustring, T, FuncCmpStrings >& map,
@@ -1187,6 +1204,8 @@ class ChartData
 class ChartElem : public StringDefElem
 {
     public:
+        using GValue = Glib::Value< ChartElem* >;
+
         static const Ustring DEFINITION_DEFAULT;
         static const Ustring DEFINITION_DEFAULT_Y; // temporary: needed for diary v1050 support
 
@@ -1199,7 +1218,7 @@ class ChartElem : public StringDefElem
         const R2Pixbuf&         get_icon() const override;
 };
 
-typedef std::map< Ustring, ChartElem*, FuncCmpStrings > MapUstringChartElem;
+using MapUstringChartElem = MapUstringDiaryElem< ChartElem >;
 
 } // end of namespace LIFEO
 
