@@ -206,6 +206,16 @@ Entry::get_prev_unfiltered( FiltererContainer* fc ) const
     return nullptr;
 }
 
+Entry*
+Entry::get_prev_straight( bool F_go_up ) const
+{
+    if ( m_p2prev )
+    {
+        auto&& descendants { m_p2prev->get_descendants() };
+        return( descendants.empty() ? m_p2prev : descendants.back() );
+    }
+    else return m_p2parent;
+}
 Entry*
 Entry::get_next_straight( bool F_go_down ) const
 {
@@ -992,8 +1002,15 @@ Entry::insert_text( UstringSize pos, const Ustring& new_text, const ListHiddenFo
                                         F_inherit_style && !para_inherit );
             pos_split = 0;
 
-            if( F_inherit_style && para_inherit && !para_inherit->is_empty() )
-                para->inherit_style_from( para_inherit, false );
+            if( F_inherit_style && para_inherit )
+                para->inherit_style_from( para_inherit,
+                                          para_inherit->is_empty() && !para->is_empty() );
+            // remove heading and hrule properties from empty paragraphs:
+            if( para_inherit->is_empty() )
+            {
+                para_inherit->set_hrule( false );
+                para_inherit->set_heading_level( VT::PS_NOTHDR );
+            }
 
             pos_para_bgn += ( para->get_size() + 1 );   // +1 for the \n
             pos_in_para = 0;
@@ -1140,7 +1157,7 @@ Entry::replace_text_with_styles( UstringSize pos_bgn, UstringSize pos_end, Parag
                                1, pos_end, pos_bgn + para_new_1st->get_chain_length() );
 
     // INSERT THE NEW TEXT
-    if( pos_split > 0 )
+    if( pos_split >= 0 )
         para_split = para->split_at( pos_split );
     para->insert_text( pos_split, para_new_1st, nullptr );  // first para is inserted
     // we normally don't access the parser directly, but here it makes sense:
@@ -1532,7 +1549,7 @@ Entry::move_paras_up( Paragraph* para_bgn, Paragraph* para_end )
 
     // move collapsed paragraphs together with their children:
     if( !para_end->is_expanded() )
-        para_end = para_end->get_sub_last();
+        para_end = para_end->get_sub_last_invisible();
 
     remove_paragraphs( para_bgn, para_end );
     add_paragraph_after( para_bgn, para_prev->m_p2prev );
@@ -1556,7 +1573,7 @@ Entry::move_paras_down( Paragraph* para_bgn, Paragraph* para_end )
 
     // move collapsed paragraphs together with their children:
     if( !para_end->is_expanded() )
-        para_end = para_end->get_sub_last();
+        para_end = para_end->get_sub_last_invisible();
 
     // skip hidden sub-paragraphs:
     if( !para_next->is_expanded() && para_next->has_subs() )
@@ -1751,7 +1768,7 @@ Entry::get_sub_tag_lowest( const Entry* tag ) const
             {
                 if( sub_tag_lowest )
                 {
-                    if( sub_tag->get_list_order() < sub_tag_lowest->get_list_order() )
+                    if( sub_tag->get_sibling_order() < sub_tag_lowest->get_sibling_order() )
                         sub_tag_lowest = sub_tag;
                 }
                 else
@@ -1777,7 +1794,7 @@ Entry::get_sub_tag_highest( const Entry* tag ) const
             {
                 if( sub_tag_highest )
                 {
-                    if( sub_tag->get_list_order() > sub_tag_highest->get_list_order() )
+                    if( sub_tag->get_sibling_order() > sub_tag_highest->get_sibling_order() )
                         sub_tag_highest = sub_tag;
                 }
                 else
