@@ -164,12 +164,14 @@ class Paragraph : public DiaryElemDataSrc
         { return m_p2next; }
         Paragraph*                  get_next_visible() const;
         Paragraph*                  get_next_sibling() const;
+        std::list< Paragraph* >     get_siblings() const;
         Paragraph*                  get_parent() const;
         Paragraph*                  get_nth_next( int );
         Paragraph*                  get_last() const;
         Paragraph*                  get_sub_last() const;
         Paragraph*                  get_sub_last_visible( bool = false ) const;
-        bool                        is_sub( const Paragraph* p_sub ) const
+        Paragraph*                  get_sub_last_invisible() const;
+        bool                        is_parent_of( const Paragraph* p_sub ) const
         {
             if( p_sub )
             {
@@ -192,7 +194,7 @@ class Paragraph : public DiaryElemDataSrc
             return false;
         }
         bool                        has_subs() const
-        { return( !is_header() && is_sub( m_p2next ) ); }
+        { return( !is_header() && is_parent_of( m_p2next ) ); }
 
         int                         get_para_no() const
         { return m_order_in_host; }
@@ -228,6 +230,8 @@ class Paragraph : public DiaryElemDataSrc
         // TEXTUAL CONTENTS
         bool                        is_empty() const
         { return m_text.empty(); }
+        bool                        is_empty_completely() const
+        { return( m_text.empty() && !is_list() ); }
         gunichar                    get_char( UstringSize i ) const
         { return m_text[ i ]; }
         const Ustring&              get_text() const
@@ -349,6 +353,11 @@ class Paragraph : public DiaryElemDataSrc
                 default:            return ES::NOT_TODO;
             }
         }
+        int                         get_todo_status_ps() const
+        {
+            const auto style { m_style & VT::PS_FLT_LIST };
+            return( ( style & VT::PS_TODO_GEN ) ? style : 0 );
+        }
         bool                        is_todo_status_forced() const
         { return( m_style & VT::PS_TODO_FORCED ); }
         void                        set_todo_status_forced( bool F_forced )
@@ -534,15 +543,13 @@ class Paragraph : public DiaryElemDataSrc
         { m_style = ( ( m_style & ~VT::PS_FLT_TYPE ) | ( type & VT::PS_FLT_TYPE ) ); }
         void                        set_para_type2( int type );
 
-        void                        change_ordered_list_type();
-
         // INDENTATION
         int                         get_indent_level() const
         { return( m_style & VT::PS_FLT_INDENT ) >> 24; }
 
         bool                        set_indent_level( int );
-        void                        indent();
-        void                        unindent();
+        bool                        indent();
+        bool                        unindent();
 
         int                         m_style{ VT::PS_DEFAULT };
         Entry*                      m_host;
