@@ -1311,7 +1311,7 @@ Cipher::init()
     // http://www.gnupg.org/documentation/manuals/gcrypt/Initializing-the-library.html
 
     // initialize subsystems:
-    if( ! gcry_check_version( NULL ) )  // TODO: check version
+    if( ! gcry_check_version( NULL ) )  // TODO: 3.2 check version
     {
         print_error( "Libgcrypt version mismatch" );
         return false;
@@ -1591,24 +1591,24 @@ EntryClear::handle_icon_release( Gtk::Entry::IconPosition pos )
 void
 EntryClear::on_changed()
 {
-    // TODO: setting icon of an entry hosted in a popopver creates problems in gtkmm4
-    // if( get_text().empty() )
-    // {
-    //     unset_icon( Gtk::Entry::IconPosition::SECONDARY );
-    //     set_icon_activatable( false, Gtk::Entry::IconPosition::SECONDARY );
-    // }
-    // else
-    // {
-    //     try // may not work!
-    //     {
-    //         set_icon_from_icon_name( "edit-clear-symbolic", Gtk::Entry::IconPosition::SECONDARY );
-    //     }
-    //     catch( ... )
-    //     {
-    //         set_icon_from_icon_name( "edit-clear", Gtk::Entry::IconPosition::SECONDARY );
-    //     }
-    //     set_icon_activatable( true, Gtk::Entry::IconPosition::SECONDARY );
-    // }
+    // be watchful: setting icon of an entry hosted in a popopver used to creates problems in gtkmm4
+    if( get_text().empty() )
+    {
+        unset_icon( Gtk::Entry::IconPosition::SECONDARY );
+        set_icon_activatable( false, Gtk::Entry::IconPosition::SECONDARY );
+    }
+    else
+    {
+        try // may not work!
+        {
+            set_icon_from_icon_name( "edit-clear-symbolic", Gtk::Entry::IconPosition::SECONDARY );
+        }
+        catch( ... )
+        {
+            set_icon_from_icon_name( "edit-clear", Gtk::Entry::IconPosition::SECONDARY );
+        }
+        set_icon_activatable( true, Gtk::Entry::IconPosition::SECONDARY );
+    }
 
     Gtk::Entry::on_changed();
 }
