@@ -616,6 +616,114 @@ compare_dates( const DateV& date_l, const DateV& date_r )
     return( date_l > date_r );
 }
 
+// CUSTOM CONTAINER OR POLLING OBJECTS =============================================================
+template< typename KeyType >
+class PollMap
+{
+    public:
+        // Insert or update
+        void
+        set( const KeyType& key, const int value )
+        {
+            auto it { key_to_value.find( key ) };
+            if( it != key_to_value.end() )
+            {
+                int   old_value { it->second };
+                auto  range     { value_to_key.equal_range( old_value ) };
+                for( auto v_it = range.first; v_it != range.second; ++v_it )
+                {
+                    if( v_it->second == key )
+                    {
+                        value_to_key.erase( v_it );
+                        break;
+                    }
+                }
+            }
+            key_to_value[ key ] = value;
+            value_to_key.insert( { value, key } );
+        }
+
+        void
+        increase( const KeyType& key )
+        {
+            auto  it    { key_to_value.find( key ) };
+            int   value { 0 };
+            if( it != key_to_value.end() )
+            {
+                value = it->second;
+                auto range { value_to_key.equal_range( value ) };
+                for( auto v_it = range.first; v_it != range.second; ++v_it )
+                {
+                    if( v_it->second == key )
+                    {
+                        value_to_key.erase( v_it );
+                        break;
+                    }
+                }
+            }
+            ++value;
+            key_to_value[ key ] = value;
+            value_to_key.insert( { value, key } );
+        }
+
+        // Get value by key
+        int
+        get_value( const KeyType& key ) const
+        {
+            auto it { key_to_value.find( key ) };
+            if( it == key_to_value.end() )
+                throw std::out_of_range( "Key not found" );
+            return it->second;
+        }
+
+        // Get the key with the lowest value
+        KeyType
+        get_key_min() const
+        {
+            if( value_to_key.empty() )
+                throw std::runtime_error( "Map is empty" );
+            return value_to_key.begin()->second;
+        }
+        KeyType
+        get_key_max() const
+        {
+            if( value_to_key.empty() )
+                throw std::runtime_error( "Map is empty" );
+            return value_to_key.rbegin()->second;
+        }
+
+        // Remove a key
+        void
+        remove( const KeyType& key )
+        {
+            auto it { key_to_value.find( key ) };
+            if( it != key_to_value.end() )
+            {
+                int   value { it->second };
+                auto  range { value_to_key.equal_range(value) };
+                for( auto v_it = range.first; v_it != range.second; ++v_it )
+                {
+                    if( v_it->second == key )
+                    {
+                        value_to_key.erase( v_it );
+                        break;
+                    }
+                }
+                key_to_value.erase( it );
+            }
+        }
+
+        // Size of the container
+        size_t size() const { return key_to_value.size(); }
+        // Check if empty
+        bool empty() const { return key_to_value.empty(); }
+
+    private:
+        std::map< KeyType, int >      key_to_value;
+        std::multimap< int, KeyType > value_to_key;
+};
+
+
 // CONSOLE MESSAGES ================================================================================
 class Console
 {
