@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-    Copyright (C) 2007-2020 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2024 Ahmet Öztürk (aoz_2@yahoo.com)
 
     This file is part of Lifeograph.
 
@@ -24,17 +24,8 @@
 #include <config.h>
 #endif
 
-#ifdef _WIN32
-#include <winsock2.h> // to silence warnings on Windows
-#endif
-
 #include <gtkmm/application.h>
 
-extern "C"
-{
-#include <clutter-gtk/clutter-gtk.h>
-}
-
 #include "lifeograph.hpp"
 
 
@@ -45,12 +36,12 @@ main( int argc, char* argv[] )
 
     // INIT PATHS
 #ifdef _WIN32
-    const std::string bindir{ HELPERS::get_exec_path() };
-    Lifeograph::BINPATH     = bindir + "/lifeograph.exe";
-    Lifeograph::SHAREDIR    = bindir + "/../share/lifeograph";
-    Lifeograph::MANUALPATH  = bindir + "/../share/lifeograph/diaries/Lifeograph Manual";
-    Lifeograph::EXAMPLEDIARYPATH = bindir + "/../share/lifeograph/diaries/example.diary";
-    Lifeograph::LOCALEDIR   = bindir + "/../share/locale";
+    const String bindir { HELPERS::get_exec_path() };
+    Lifeograph::BINPATH     = bindir + "\\bin\\lifeograph.exe";
+    Lifeograph::SHAREDIR    = bindir + "\\share\\" + PACKAGE;
+    Lifeograph::MANUALPATH  = Lifeograph::SHAREDIR + "\\diaries\\Lifeograph Manual";
+    Lifeograph::EXAMPLEDIARYPATH = Lifeograph::SHAREDIR + "\\diaries\\example.diary";
+    Lifeograph::LOCALEDIR   = bindir + "\\share\\locale";
 
     PRINT_DEBUG( "SHAREDIR: ", Lifeograph::SHAREDIR );
 #else
@@ -72,8 +63,5 @@ main( int argc, char* argv[] )
     // APPLICATION
     Glib::RefPtr< LIFEO::Lifeograph > app = Lifeograph::create();
 
-    if( gtk_clutter_init( &argc, &argv ) != CLUTTER_INIT_SUCCESS )
-        return 1;
-
     return app->run( argc, argv );
 }
