@@ -70,7 +70,7 @@ class Settings
         bool                        use_imperial_units{ false };
 
         bool                        save_backups{ false };
-        std::string                 backup_folder_path;
+        String                      backup_folder_uri;
 
         std::string                 diary_extension{ EXTENSION_DEFAULT };
 
