@@ -80,7 +80,7 @@ WidgetEntryList::handle_setup_row( const Glib::RefPtr< Gtk::ListItem >& list_ite
     auto label    = Gtk::make_managed< Gtk::Label >();
     auto I_fav    = Gtk::make_managed< Gtk::Image >( Lifeograph::icons->favorite_16 );
 
-    // TODO: we may add this as an option on v3.1:
+    // TODO: 3.1: we may add this as an option on v3.1:
     // Pango::AttrList attrs;
     // auto&&          attrscale{ Pango::Attribute::create_attr_scale( 0.9 ) };
     // attrs.insert( attrscale );
@@ -113,7 +113,7 @@ WidgetEntryList::handle_bind_row( const Glib::RefPtr< Gtk::ListItem >& list_item
     expander->set_list_row( row );
     // expander->set_indent_for_icon( true ); // this is the default it seems
 
-    gentry->m_p2entry->set_list_order( row->get_position() );
+    m_map_rows[ gentry->m_p2entry->get_id() ] = row;
 
     // note that when an entry is collapsed, its sub-entries are also collapsed automatically
     if( gentry->m_p2entry->get_child_1st() )
@@ -152,16 +152,17 @@ WidgetEntryList::handle_bind_row( const Glib::RefPtr< Gtk::ListItem >& list_item
         sigc::bind( sigc::mem_fun( *this, &WidgetEntryList::handle_drag_prepare ),
                     drag_source, gentry ),
         false );
-    // drag_source->signal_drag_end().connect(
-    //     sigc::mem_fun( *this, &WidgetEntryList::handle_drag_end ), false );
+    drag_source->signal_drag_end().connect(
+            [ this ]( const Glib::RefPtr< Gdk::Drag >&, bool )
+            {
+                m_id_dragged_entry = DEID_UNSET;
+                m_drop_position = DropPosition::NONE;
+                queue_draw();
+            } );
     expander->add_controller( drag_source );
 
     auto drop_target { Gtk::DropTarget::create( G_TYPE_INVALID,
-#ifdef _WIN32
-                                                Gdk::DragAction::COPY ) };
-#else
                                                 Gdk::DragAction::COPY|Gdk::DragAction::MOVE ) };
-#endif // _WIN32
 
     drop_target->set_gtypes( { Glib::Value< Ustring >::value_type(),
                                Theme::GValue::value_type(),
@@ -169,18 +170,8 @@ WidgetEntryList::handle_bind_row( const Glib::RefPtr< Gtk::ListItem >& list_item
                                EntrySelection::GValue::value_type() } );
     drop_target->signal_motion().connect(
             sigc::bind( sigc::mem_fun( *this, &WidgetEntryList::handle_drop_motion ),
-                        drop_target, expander ),
+                        drop_target, expander, gentry->m_p2entry ),
             false );
-    drop_target->signal_enter().connect(
-            [ this ]( double, double )
-            {
-                m_drop_coord_x = -1.0;
-                m_drop_position = DropPosition::NONE;
-                return Gdk::DragAction::COPY;
-            },
-            false );
-    // drop_target->signal_leave().connect(
-    //         [ this ]() { m_drop_coord_x = -1.0; m_drop_position = DropPosition::NONE; } );
     drop_target->signal_drop().connect(
             sigc::bind( sigc::mem_fun( *this, &WidgetEntryList::handle_drop ),
                         gentry->m_p2entry ),
@@ -195,7 +186,11 @@ WidgetEntryList::handle_unbind_row( const Glib::RefPtr< Gtk::ListItem >& list_it
     auto gentry { std::dynamic_pointer_cast< GObjectEntry >( row->get_item() ) };
 
     if( gentry )
+    {
         gentry->m_connection_expand.disconnect();
+        m_map_rows.erase( gentry->m_p2entry->get_id() );
+        PRINT_DEBUG( "handle_UNbind:", gentry->m_p2entry->get_name() );
+    }
 }
 
 void
@@ -259,8 +254,18 @@ WidgetEntryList::populate()
         }
     }
 
-    m_selection_model->signal_selection_changed().connect(
-            sigc::mem_fun( *this, &WidgetEntryList::handle_selection_changed ) );
+    // the following is the standard way but does not fire when the active entry...
+    // ...is a child of a collapsed parent and the parent is selected:
+    // m_selection_model->signal_selection_changed().connect(
+    //         sigc::mem_fun( *this, &WidgetEntryList::handle_selection_changed
+    //         ) );
+
+    auto gesture_click { Gtk::GestureClick::create() };
+    gesture_click->set_button( 1 );
+    gesture_click->signal_released().connect(
+                [ this ]( int, double, double ) { handle_selection_changed(); } );
+
+    add_controller( gesture_click );
 
     set_model( m_selection_model );
 
@@ -273,21 +278,27 @@ WidgetEntryList::select( Entry* p2entry )
     m_selected_entries.clear();
 
     Lifeograph::START_INTERNAL_OPERATIONS();
+
     if( p2entry )
     {
         p2entry = p2entry->get_first_exposed_upwards();
-        get_model()->select_item( p2entry->get_list_order(), true );
-        m_selected_entries.insert( p2entry );
+        const auto order { get_entry_order( p2entry ) };
+        if( order >= 0 )
+        {
+            get_model()->select_item( order, true );
+            m_selected_entries.insert( p2entry );
+        }
     }
     else
         get_model()->unselect_all();
+
     Lifeograph::FINISH_INTERNAL_OPERATIONS();
 }
 
 void
 WidgetEntryList::scroll_to_entry( const Entry* p2entry )
 {
-    const int order { p2entry->get_list_order() };
+    const auto order { get_entry_order( p2entry ) };
 
     Lifeograph::START_INTERNAL_OPERATIONS();
     scroll_to( order < 6 ? 0 : ( order - 5 ), Gtk::ListScrollFlags::NONE, {} );
@@ -323,21 +334,13 @@ WidgetEntryList::present_entry( const Entry* p2entry )
     scroll_to_and_select_entry( p2entry->get_first_exposed_upwards() );
 }
 
-void
-WidgetEntryList::expand_entry( const Entry* p2entry ) // this function does not do much
-{
-    Lifeograph::START_INTERNAL_OPERATIONS();
-    m_TLM->get_row( p2entry->get_list_order() )->set_expanded( true );
-    Lifeograph::FINISH_INTERNAL_OPERATIONS();
-}
-
 void
 WidgetEntryList::refresh_row( const Entry* entry )
 {
     if( Lifeograph::is_internal_operations_ongoing() || !m_TLM || !entry->is_exposed_in_list() )
         return;
 
-    auto row    { m_TLM->get_row( entry->get_list_order() ) };
+    auto row    { get_entry_row( entry ) };
     if( !row ) return;
     auto gentry { std::dynamic_pointer_cast< GObjectEntry >( row->get_item() ) };
     if( !gentry ) return;
@@ -354,7 +357,7 @@ WidgetEntryList::refresh_row_label( const Entry* entry )
     if( Lifeograph::is_internal_operations_ongoing() || !m_TLM || !entry->is_exposed_in_list() )
         return;
 
-    auto row    { m_TLM->get_row( entry->get_list_order() ) };
+    auto row    { get_entry_row( entry ) };
     if( !row ) return;
     auto gentry { std::dynamic_pointer_cast< GObjectEntry >( row->get_item() ) };
     if( !gentry ) return;
@@ -363,46 +366,14 @@ WidgetEntryList::refresh_row_label( const Entry* entry )
     gentry->m_L->set_sensitive( !entry->is_trashed() );
 }
 
-void
-WidgetEntryList::go_up()
-{
-    if( m_selected_entries.empty() ) return;
-
-    Entry* entry { *m_selected_entries.begin() };
-
-    if( entry == nullptr || entry->get_list_order() < 1 )
-        return;
-
-    auto row    { m_TLM->get_row( entry->get_list_order() - 1 ) };
-    auto gentry { std::dynamic_pointer_cast< GObjectEntry >( row->get_item() ) };
-
-    if( gentry )
-        select( gentry->m_p2entry );
-}
-
-void
-WidgetEntryList::go_down()
-{
-    if( m_selected_entries.empty() ) return;
-
-    Entry* entry { *m_selected_entries.begin() };
-
-    if( entry == nullptr || entry->get_list_order() > int( m_TLM->property_n_items() - 2 ) )
-        return;
-
-    auto row    { m_TLM->get_row( entry->get_list_order() + 1 ) };
-    auto gentry { std::dynamic_pointer_cast< GObjectEntry >( row->get_item() ) };
-
-    if( gentry )
-        select( gentry->m_p2entry );
-}
-
 void
 WidgetEntryList::toggle_selected_collapsed()
 {
     if( m_selected_entries.empty() ) return;
 
-    auto row { m_TLM->get_row( ( *m_selected_entries.begin() )->get_list_order() ) };
+    Entry*  entry  { *m_selected_entries.begin() };
+    if( !entry ) return;
+    auto    row    { get_entry_row( entry ) };
     if( !row ) return;
 
     row->set_expanded( !row->get_expanded() );
@@ -421,10 +392,12 @@ WidgetEntryList::handle_menu_click( int n_press, double x, double y,
 
     // if( !F_ctrl_or_shift_pressed )
 
-    auto pt { gentry->m_Bx->compute_point( *AppWindow::p, Gdk::Graphene::Point( x, y ) ) };
+    auto pt   { gentry->m_Bx->compute_point( *AppWindow::p, Gdk::Graphene::Point( x, y ) ) };
+    auto row  { get_entry_row( gentry->m_p2entry ) };
+    if( !row ) return;
 
-    if( !get_model()->is_selected( gentry->m_p2entry->get_list_order() ) )
-        get_model()->select_item( gentry->m_p2entry->get_list_order(), true );
+    if( !get_model()->is_selected( row->get_position() ) )
+        get_model()->select_item( row->get_position(), true );
 
     AppWindow::p->UI_diary->show_Po_entry( gentry->m_p2entry,
                                            Gdk::Rectangle( pt->get_x(), pt->get_y(), 1, 1 ) );
@@ -519,6 +492,7 @@ WidgetEntryList::handle_drag_prepare( double x, double y,
         value_multi.set( &m_selected_entries );
 
         drag_source->set_icon( lookup_default_icon( "entry_plus-16", 16 ), 0, 0 );
+        m_id_dragged_entry = DEID_MULTIPLE;
 
         return Gdk::ContentProvider::create( value_multi );
     }
@@ -530,6 +504,7 @@ WidgetEntryList::handle_drag_prepare( double x, double y,
 
         auto widget_paintable { Gtk::WidgetPaintable::create( *gentry->m_Bx ) };
         drag_source->set_icon( widget_paintable, 0, 0 );
+        m_id_dragged_entry = gentry->m_p2entry->get_id();
 
         return Gdk::ContentProvider::create( value_entry );
     }
@@ -544,27 +519,37 @@ WidgetEntryList::handle_drag_prepare( double x, double y,
 Gdk::DragAction
 WidgetEntryList::handle_drop_motion( double x, double y,
                                      Glib::RefPtr< Gtk::DropTarget >& drop_target,
-                                     Gtk::TreeExpander* expander )
+                                     Gtk::TreeExpander* expander,
+                                     Entry* target_entry )
 {
-    // if( m_line_height < 1 && m_TLM->get_n_items() > 0 )
-    // {
-    //     auto gentry
-    //     { std::dynamic_pointer_cast< GObjectEntry >( m_TLM->get_row( 0 )->get_item() ) };
+    auto pt       { expander->compute_point( *this, Gdk::Graphene::Point( x, 0.0 ) ) };
+    auto pt_2     { expander->compute_point( *this, Gdk::Graphene::Point( 0.0, 0.0 ) ) };
+    auto dp_new   { DropPosition::NONE };
+    auto formats  { drop_target->get_formats() };
+    auto action   { Gdk::DragAction::COPY };
+
+    // disable dropping onto itself:
+    if( m_id_dragged_entry == target_entry->get_id() )
+    {
+        PRINT_DEBUG( "contains entry");
+        action = Gdk::DragAction::MOVE;
+        return Gdk::DragAction( 0 );
+    }
+    else if( m_id_dragged_entry == DEID_MULTIPLE )
+    {
+        PRINT_DEBUG( "contains multiple entries");
+        action = Gdk::DragAction::MOVE;
+        if( m_selected_entries.find( target_entry ) != m_selected_entries.end() )
+            return Gdk::DragAction( 0 );
+    }
 
-    //     if( gentry )
-    //         m_line_height = gentry->m_Bx->get_height();
-    // }
     if( m_line_height < 1 )
         m_line_height = expander->get_height();
 
-    auto pt     { expander->compute_point( *this, Gdk::Graphene::Point( x, 0.0 ) ) };
-    auto dp_new { DropPosition::NONE };
-
-    m_drop_coord_x = pt->get_x() - x;
+    m_drop_coord_x = pt_2->get_x();
 
     // EVALUATE THE HOVERED ELEMENT
-    // TODO: disable dropping an element onto itself
-    if     ( pt->get_x() < OFFSET_DROP_INTO )
+    if     ( pt->get_x() < OFFSET_DROP_INTO || m_id_dragged_entry == DEID_UNSET )
     {
         dp_new = DropPosition::INTO;
         m_drop_coord_y = pt->get_y();
@@ -589,20 +574,8 @@ WidgetEntryList::handle_drop_motion( double x, double y,
         queue_draw();
     }
 
-    // ACTION TYPE --Windows does not support DragAction::MOVE for some reason
-#ifdef _WIN32
-    return Gdk::DragAction::COPY;
-#else
-    auto value { drop_target->get_value() };
-
-    if( G_VALUE_HOLDS( value.gobj(), Glib::Value< Ustring >::value_type() ) ||
-        G_VALUE_HOLDS( value.gobj(), Theme::GValue::value_type() ) )
-    {
-        return Gdk::DragAction::COPY;
-    }
-    else
-        return Gdk::DragAction::MOVE;
-#endif // _WIN32
+    // ACTION TYPE
+    return action;
 }
 
 void
@@ -697,12 +670,12 @@ WidgetEntryList::handle_drop( const Glib::ValueBase& value, double x, double y,
     }
 
     m_drop_position = DropPosition::NONE;
-    m_drop_coord_x = -1;
+    m_id_dragged_entry = DEID_UNSET;
     return F_ret_val;
 }
 
 void
-WidgetEntryList::handle_selection_changed( guint pos, guint n_items )
+WidgetEntryList::handle_selection_changed( /*guint pos, guint n_items*/ )
 {
     // NOTE: we did not use the pos & n_items as it turned out to be quite hard
     // to keep an uptodate list of selected items
@@ -739,7 +712,7 @@ WidgetEntryList::snapshot_vfunc( const Glib::RefPtr< Gtk::Snapshot >& snapshot )
 
     Gtk::ListView::snapshot_vfunc( snapshot );
 
-    if( m_drop_position != DropPosition::NONE || m_drop_coord_x >= 0 )
+    if( m_drop_position != DropPosition::NONE || m_id_dragged_entry != DEID_UNSET )
     {
         const int       w       { get_width() };
         const int       h       { get_height() };
@@ -755,7 +728,7 @@ WidgetEntryList::snapshot_vfunc( const Glib::RefPtr< Gtk::Snapshot >& snapshot )
             cr->fill();
         }
 
-        if( m_drop_coord_x >= 0 )
+        if( m_id_dragged_entry != DEID_UNSET ) // only true for entries
         {
             Gdk::Cairo::set_source_rgba( cr, Gdk::RGBA( "#CC3333AA" ) );
             cr->set_line_width( 2.0 );
@@ -785,7 +758,11 @@ WidgetEntryList::handle_expand_changed( const Glib::RefPtr< Gtk::TreeListRow >&
     if( !gentry ) return;
     gentry->m_p2entry->set_expanded( row->get_expanded() );
     if( !row->get_expanded() )
-        gentry->m_p2entry->do_for_each_descendant( []( Entry* e ) { e->set_list_order( -1 ); } );
+    {
+        if( AppWindow::p->UI_entry->get_cur_entry()->is_descendant_of( gentry->m_p2entry ) )
+            Glib::signal_idle().connect_once(
+                    [ this ](){ select( AppWindow::p->UI_entry->get_cur_entry() ); } );
+    }
 
     PRINT_DEBUG( "entry [", gentry->m_p2entry->get_name(),
                  "] new expand state: ", row->get_expanded() );
