@@ -65,6 +65,18 @@ class WidgetEntryList : public Gtk::ListView
         void                        clear_and_disable();
         void                        populate();
 
+        int                         get_entry_order( const Entry* p2entry ) const
+        {
+            auto kv_row = m_map_rows.find( p2entry->get_id() );
+            return( kv_row != m_map_rows.end() ? kv_row->second->get_position() : -1 );
+        }
+        Glib::RefPtr< Gtk::TreeListRow >
+        get_entry_row( const Entry* p2entry ) const
+        {
+            auto kv_row = m_map_rows.find( p2entry->get_id() );
+            return( kv_row != m_map_rows.end() ? kv_row->second : nullptr );
+        }
+
         void                        select( Entry* );
         int                         get_selected_count() const
         { return m_selection_model->get_selection()->get_size(); }
@@ -76,13 +88,9 @@ class WidgetEntryList : public Gtk::ListView
         }
         void                        present_entry_hard( const Entry* );
         void                        present_entry( const Entry* );
-        void                        expand_entry( const Entry* );
         void                        refresh_row( const Entry* );
         void                        refresh_row_label( const Entry* );
 
-        void                        go_up();
-        void                        go_down();
-
         // Gdk::Rectangle              get_item_rect( const Entry* ) const;
 
         void                        toggle_selected_collapsed();
@@ -109,10 +117,10 @@ class WidgetEntryList : public Gtk::ListView
         // void                        handle_drag_end( const Glib::RefPtr< Gdk::Drag >&, bool );
         Gdk::DragAction             handle_drop_motion( double, double,
                                                         Glib::RefPtr< Gtk::DropTarget >&,
-                                                        Gtk::TreeExpander* );
+                                                        Gtk::TreeExpander*, Entry* );
         bool                        handle_drop( const Glib::ValueBase&, double, double, Entry* );
 
-        void                        handle_selection_changed( guint, guint );
+        void                        handle_selection_changed(/* guint, guint */);
 
         void                        handle_expand_changed( const Glib::RefPtr< Gtk::TreeListRow >& );
 // tried to use it for filtering by tagged but did not work well:
@@ -121,7 +129,11 @@ class WidgetEntryList : public Gtk::ListView
         void                        size_allocate_vfunc( int, int, int ) override;
         void                        snapshot_vfunc( const Glib::RefPtr< Gtk::Snapshot >& ) override;
 
+        using MapRowEntries = std::map< DEID, Glib::RefPtr< Gtk::TreeListRow > >;
+
+        MapRowEntries               m_map_rows;
         EntrySelection              m_selected_entries; // multiple entry selection
+        DEID                        m_id_dragged_entry { DEID_UNSET }; // single entry case
         EntrySelection              m_cut_entries;
 
         void                        handle_setup_row( const Glib::RefPtr< Gtk::ListItem >& );
